/*************************************************
* Mardi.hpp
* Copyright (c) Rennie deGraaf, 2005.  All rights reserved.
* $Id: Mardi.hpp 20 2005-07-27 01:03:31Z degraaf $
*
* Class encapsulating a set of Trackers, monitoring them and logging values
* tracked.  See Mardi.cpp for further details.
*
* This file is part of Mardi.
*
* Mardi is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* Mardi is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with Mardi; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
**************************************************/

#ifndef MARDI_HPP
#define MARDI_HPP

//#include <exception>
#include <string>
#include <cstdio>
#include <list>
#include <ctime>
using namespace std;
#include "Tracker.hpp"

class Mardi
{
  public:
    /*class BadConfigException : public std::exception
    {
      public:
        BadConfigException(string d);
        const char* what() const throw();
        ~BadConfigException() throw();
      protected:
        string desc;
    };*/
    Mardi();
    ~Mardi();
    void load(const string file); //throw (BadConfigException);
    void checkAll();
    void init();
    unsigned getInterval() const;
    FILE* getLog() const;
    string getDefaultOverCmd() const;
    string getDefaultUnderCmd() const;
    string getDefaultUser() const;
    string getDefaultGroup() const;
  private:
    list<Tracker> trackers; // all trackers in the system
    unsigned interval;      // the interval between updating trackers
    string logname;         // the name of the file in which to log tracker values
    FILE* log;              // the file stream to which to write tracker values
    string defaultOverCmd;  // the default command to execute if an upper bound is exceeded
    string defaultUnderCmd; // the default command to execute if a lower bound is exceeded
    string defaultUser;     // the default user under which to run commands
    string defaultGroup;    // the default group under which to run commands
    time_t start;           // the time at which the system started
};


#ifndef _MAIN_
extern Mardi mardi;
#endif

#endif // MARDI_HPP
